# remirepo spec file for php-doctrine-lexer, from:
#
# Fedora spec file for php-doctrine-lexer
#
# Copyright (c) 2013-2019 Shawn Iwinski <shawn.iwinski@gmail.com>
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#
# Github
%global github_owner     doctrine
%global github_name      lexer
%global github_version   1.2.0
%global github_commit    5242d66dbeb21a30dd8a3e66bf7a73b66e05e1f6
%global github_short     %(c=%{github_commit}; echo ${c:0:7})
# Namespace
%global ns_vendor        Doctrine
%global ns_project       Common
%global ns_subproj       Lexer
# Packagist
%global composer_vendor  doctrine
%global composer_project lexer

# "php": ">=7.2"
%global php_min_ver      7.2

%{!?phpdir:  %global phpdir  %{_datadir}/php}
%global with_tests       0%{!?_without_tests:1}

Name:          php-%{composer_vendor}-%{composer_project}
Version:       %{github_version}
Release:       1%{?github_release}%{?dist}
Summary:       Base library for a lexer that can be used in top-down, recursive descent parsers

License:       MIT
URL:           https://github.com/%{github_owner}/%{github_name}
# git snapshot with tests
Source0:       %{name}-%{github_version}-%{github_short}.tgz
Source1:       makesrc.sh

BuildArch:     noarch
BuildRequires: php-fedora-autoloader-devel
%if %{with_tests}
BuildRequires: php(language) >= %{php_min_ver}
BuildRequires: php-pcre
BuildRequires: php-reflection
BuildRequires: phpunit8
%endif

# composer.json
Requires:      php(language) >= %{php_min_ver}
# phpcompatinfo (computed from version 1.1.0)
Requires:      php-pcre
Requires:      php-reflection
# Autoloader
Requires:      php-composer(fedora/autoloader)

# Composer
Provides:      php-composer(%{composer_vendor}/%{composer_project}) = %{version}

%description
Base library for a lexer that can be used in top-down, recursive descent
parsers.

This lexer is used in Doctrine Annotations and in Doctrine ORM (DQL).

Autoloader: %{phpdir}/%{ns_vendor}/%{ns_project}/%{ns_subproj}/autoload.php


%prep
%setup -qn %{github_name}-%{github_commit}


%build
: Generate a simple autoloader
%{_bindir}/phpab \
    --output lib/%{ns_vendor}/%{ns_project}/%{ns_subproj}/autoload.php \
    --template fedora \
    lib/%{ns_vendor}/%{ns_project}


%install
mkdir -p %{buildroot}%{phpdir}
cp -rp lib/* %{buildroot}%{phpdir}/


%check
%if %{with_tests}
: Generate autoloader
mkdir vendor
%{_bindir}/phpab \
    --output vendor/autoload.php \
    --template fedora \
    tests

cat << 'EOF' | tee -a vendor/autoload.php
require "%{buildroot}%{_datadir}/php/%{ns_vendor}/%{ns_project}/%{ns_subproj}/autoload.php";
EOF

# we don't want PHPStan (which pull nette framework)

: Run test suite
ret=0
for cmd in php php72 php73 php74; do
  if which $cmd; then
    $cmd %{_bindir}/phpunit8 \
        --bootstrap vendor/autoload.php \
        --verbose || ret=1
  fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%dir %{_datadir}/php/Doctrine
%dir %{_datadir}/php/Doctrine/Common
     %{_datadir}/php/Doctrine/Common/Lexer


%changelog
* Wed Nov 13 2019 Remi Collet <remi@remirepo.net> - 1.2.0-1
- update to 1.2.0

* Thu Aug  1 2019 Remi Collet <remi@remirepo.net> - 1.1.0-1
- update to 1.1.0
- raise dependency on PHP 7.2
- sources from git snapshot
- run upstream test suite during build
- use classmap autoloader

* Tue Jun 11 2019 Remi Collet <remi@remirepo.net> - 1.0.2-1
- update to 1.0.2

* Sat May 13 2017 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0.1-8
- Switch autoloader to php-composer(fedora/autoloader)

* Sat Jun 27 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0.1-5
- Updated autoloader with trailing separator

* Wed Jun 24 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0.1-4
- Added autoloader dependency

* Tue Jun 23 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0.1-3
- Added autoloader

* Mon Jan 05 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0.1-1
- Updated to 1.0.1 (same commit but tagged version instead of snapshot; BZ #1178808)
- %%license usage

* Sun Dec 07 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0-5.20140909git83893c5
- Updated to latest snapshot (required for php-egulias-email-validator 1.2.6)

* Fri Jun 20 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0-4.20131220gitf12a5f7
- Added php-composer(%%{composer_vendor}/%%{composer_project}) virtual provide

* Sat Jan 11 2014 Remi Collet <rpms@famillecollet.com> 1.0-2.20131220gitf12a5f7
- backport for remi repo

* Mon Jan 06 2014 Shawn Iwinski <shawn.iwinski@gmail.com> 1.0-2.20131220gitf12a5f7
- Conditional %%{?dist}

* Mon Dec 23 2013 Shawn Iwinski <shawn.iwinski@gmail.com> 1.0-1.20131220gitf12a5f7
- Initial package
